@@ -5,15 +5,15 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-kms", "1.63.0", __name__[0:-6], "aws-kms@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-kms", "1.64.0", __name__[0:-6], "aws-kms@1.64.0.jsii.tgz"
 )
 
 __all__ = [
